package VMOMI::DiagnosticManagerLogFormat;
use parent 'VMOMI::SimpleType';

use strict;
use warnings;

1;
